searchData={"items":[{"type":"module","title":"LiveCharts","doc":"LiveCharts is a library to render static and dynamic charts\nin Phoenix LiveView applications.\n\nTo get started, see the [README](https://hexdocs.pm/live_charts).\n\nLiveCharts currently comes with support for\n[ApexCharts](https://apexcharts.com/) out of the box, but it\ncan work with any JS charting library that has a\n`LiveCharts.Adapter` defined.","ref":"LiveCharts.html"},{"type":"function","title":"LiveCharts.build/1","doc":"Build a new chart config.\n\nSee `LiveCharts.Chart.build/1` for more details.","ref":"LiveCharts.html#build/1"},{"type":"function","title":"LiveCharts.chart/1","doc":"Renders a chart component.\n\nSee `LiveCharts.Components.chart/1` for more details.","ref":"LiveCharts.html#chart/1"},{"type":"function","title":"LiveCharts.push_update/3","doc":"Push a data update event to LiveView.\n\nSee `LiveCharts.Components.push_update/3` for more details.","ref":"LiveCharts.html#push_update/3"},{"type":"behaviour","title":"LiveCharts.Adapter","doc":"LiveCharts adapter specification.\n\nAdapter is a module that translates `%LiveCharts.Chart{}` struct\ninto a JS charting library specific configuration. It will usually\nexpose a LiveView hook to handle dynamic data updates as well.\n\nRight now, LiveCharts ships with only one adapter:\n`LiveCharts.Adapter.ApexCharts` (default).","ref":"LiveCharts.Adapter.html"},{"type":"behaviour","title":"Example - LiveCharts.Adapter","doc":"To define a new adapter for your favorite JS charting library, or\noverride the Hook or options, you must call `use LiveCharts.Adapter`\nand implement the required callbacks.\n\n```elixir\ndefmodule MyCustomChartAdapter do\n  use LiveCharts.Adapter\n\n  @impl true\n  def hook, do: \"MyCustomChartHook\"\n\n  @impl true\n  def build_config(%Chart{} = chart) do\n    # return a plain map representing the JS library config\n    # that should be passed to the hook\n\n    %{\n      my_js_lib: %{\n        chart_type: chart.type,\n        chart_data: chart.data,\n        # ...\n      }\n    }\n  end\nend\n```","ref":"LiveCharts.Adapter.html#module-example"},{"type":"callback","title":"LiveCharts.Adapter.build_config/1","doc":"Translate a `%Chart{}` struct to JS library-specific options","ref":"LiveCharts.Adapter.html#c:build_config/1"},{"type":"callback","title":"LiveCharts.Adapter.hook/1","doc":"Fully qualified name of the LiveView hook to call when rendering\nthe chart.","ref":"LiveCharts.Adapter.html#c:hook/1"},{"type":"module","title":"LiveCharts.Adapter.ApexCharts","doc":"LiveCharts adapter for ApexCharts.js\n\nThis adapter comes with a LiveView hook and default configs to work with ApexCharts.\n\nAll configuration options must be set under the `:options` key in the `%Chart{}`\nconfig. However, you do not need to set the following options in `chart.options`\nas they are automatically set from the `%Chart{}` config.\n\n- `options.chart.type`: Will always be determined from the `:type` key in the\n  LiveCharts config.\n\n- `options.series`: Will always be determined from the `:series` key in the\n  LiveCharts config.","ref":"LiveCharts.Adapter.ApexCharts.html"},{"type":"module","title":"Configuration - LiveCharts.Adapter.ApexCharts","doc":"```elixir\nmy_chart =\n  LiveCharts.build(%{\n    # (Optional) a unique string id to differentiate the chart from other\n    # charts on the same page. If not set, a random id will be assigned\n    # to the chart.\n    id: \"my-custom-chart-id\",\n\n    # Set the chart type. Supports `:line`, `:bar`, `:pie`, `:donut`,\n    # `:area`, and many more. For a full list of supported types, see the\n    # adapter or JS library documentation.\n    type: :line,\n\n    # A list of series data with all the datapoints to chart. Format of\n    # this data is determined by the adapter/JS library. This may also\n    # be empty, if you plan to push dynamic updates to the chart over\n    # the socket later.\n    series: [\n      %{name: \"Sales\", data: [10, 20, 30, 40, 50]},\n    ],\n\n    # (Optional) Other library and adapter-specific options.\n    options: %{\n      xaxis: %{\n        categories: [2021, 2022, 2023, 2024, 2025]\n      },\n    },\n\n    # (Optional) set the adapter to use for the chart. If not set, uses\n    # the global adapter configured in `config.exs` (defaults to\n    # `LiveCharts.Adapter.ApexCharts`).\n    adapter: LiveCharts.Adapter.ApexCharts,\n  })\n```","ref":"LiveCharts.Adapter.ApexCharts.html#module-configuration"},{"type":"module","title":"Examples - LiveCharts.Adapter.ApexCharts","doc":"","ref":"LiveCharts.Adapter.ApexCharts.html#module-examples"},{"type":"module","title":"Bar Chart (Simple) - LiveCharts.Adapter.ApexCharts","doc":"```elixir\nLiveCharts.build(%{\n  type: :bar,\n  options: %{\n    xaxis: %{\n      categories: [2011, 2012, 2013, 2014, 2015, 2016, 2017, 2018, 2019, 2020]\n    },\n    dataLabels: %{enabled: false}\n  },\n  series: [\n    %{\n      data: [43, 85, 4, 76, 56, 92, 1, 46, 75, 14]\n    }\n  ]\n})\n```","ref":"LiveCharts.Adapter.ApexCharts.html#module-bar-chart-simple"},{"type":"module","title":"Pie Chart (Simple) - LiveCharts.Adapter.ApexCharts","doc":"```elixir\nLiveCharts.build(%{\n  type: :pie,\n  series: [51, 82, 48, 65],\n  options: %{\n    labels: [\"Ali\", \"Saad\", \"Uzair\", \"Hassan\"]\n  },\n})\n```","ref":"LiveCharts.Adapter.ApexCharts.html#module-pie-chart-simple"},{"type":"module","title":"Line Chart (Multi-series) - LiveCharts.Adapter.ApexCharts","doc":"```elixir\nLiveCharts.build(%{\n  type: :line,\n  options: %{\n    xaxis: %{\n      categories: [2011, 2012, 2013, 2014, 2015, 2016, 2017, 2018, 2019, 2020]\n    }\n  },\n  series: [\n    %{\n      data: [80, 100, 44, 73, 46, 74, 14, 30, 58, 90],\n      name: \"Ali\"\n    },\n    %{\n      data: [81, 35, 59, 37, 62, 13, 61, 90, 100, 77],\n      name: \"Saad\"\n    },\n    %{\n      data: [73, 33, 42, 86, 39, 95, 28, 4, 93, 41],\n      name: \"Uzair\"\n    }\n  ]\n})\n```","ref":"LiveCharts.Adapter.ApexCharts.html#module-line-chart-multi-series"},{"type":"module","title":"Area Chart - LiveCharts.Adapter.ApexCharts","doc":"```elixir\nLiveCharts.build(%{\n  type: :area,\n  options: %{\n    xaxis: %{\n      categories: ~w(Jan Feb Mar Apr May Jun Jul Aug Sep Nov Dec)\n    },\n    dataLabels: %{enabled: false},\n    yaxis: %{max: 100, min: 0}\n  },\n  series: [\n    %{\n      data: [62, 53, 67, 65, 61, 64, 63, 59, 57, 70, 85, 80],\n      name: \"Ali\"\n    },\n    %{\n      data: [26, 41, 41, 25, 26, 21, 45, 25, 29, 48, 32, 32],\n      name: \"Saad\"\n    }\n  ]\n})\n```","ref":"LiveCharts.Adapter.ApexCharts.html#module-area-chart"},{"type":"module","title":"HeatMap Chart - LiveCharts.Adapter.ApexCharts","doc":"```elixir\nLiveCharts.build(%{\n  type: :heatmap,\n  options: %{\n    chart: %{\n      height: 600\n    },\n    colors: [\"#23700C\"],\n    dataLabels: %{\n      enabled: false\n    }\n  },\n  series: Enum.map(~w(Jan Feb Mar Apr May Jun Jul Aug Sep Nov Dec), fn month ->\n    %{\n      name: month,\n      data: Enum.map(1..5, fn i ->\n        %{\n          x: to_string(2020 + i),\n          y: random_value(min: 10, max: 80)\n        }\n      end)\n    }\n  end)\n})\n```\n\n\nLive demos for various charts are [available here](https://livecharts.stax3.com/).\nYou can also view the [source code](https://github.com/Stax3/live_charts_demo) for\nthe examples in the demo. For the full list of supported options, see\n[ApexCharts documentation](https://apexcharts.com/docs/).","ref":"LiveCharts.Adapter.ApexCharts.html#module-heatmap-chart"},{"type":"module","title":"LiveCharts.Chart","doc":"Chart struct representing initial chart data\nand configuration.\n\nTo create a new `%Chart{}`, you should use the\n`build/1` method.","ref":"LiveCharts.Chart.html"},{"type":"function","title":"LiveCharts.Chart.build/1","doc":"Create a new `%LiveCharts.Chart{}` struct","ref":"LiveCharts.Chart.html#build/1"},{"type":"type","title":"LiveCharts.Chart.series/0","doc":"Chart series type","ref":"LiveCharts.Chart.html#t:series/0"},{"type":"type","title":"LiveCharts.Chart.t/0","doc":"Chart config type","ref":"LiveCharts.Chart.html#t:t/0"},{"type":"module","title":"LiveCharts.Components","doc":"","ref":"LiveCharts.Components.html"},{"type":"function","title":"LiveCharts.Components.chart/1","doc":"Render a chart in LiveView.","ref":"LiveCharts.Components.html#chart/1"},{"type":"function","title":"Attributes - LiveCharts.Components.chart/1","doc":"* `chart` (`LiveCharts.Chart`) (required) - A `%LiveCharts.Chart{}` configuration.","ref":"LiveCharts.Components.html#chart/1-attributes"},{"type":"function","title":"LiveCharts.Components.push_update/3","doc":"Push an update event on the LiveView socket to update\nchart data.","ref":"LiveCharts.Components.html#push_update/3"},{"type":"module","title":"LiveCharts.Validator","doc":"Chart validation helpers","ref":"LiveCharts.Validator.html"},{"type":"function","title":"LiveCharts.Validator.validate/1","doc":"Validate a chart.\n\nReturns `{:ok, chart}` if chart is valid. Otherwise,\nreturns `{:error, reason}`.","ref":"LiveCharts.Validator.html#validate/1"},{"type":"function","title":"LiveCharts.Validator.validate!/1","doc":"Validate a chart, raising an error if it is invalid.","ref":"LiveCharts.Validator.html#validate!/1"},{"type":"exception","title":"LiveCharts.ValidationError","doc":"Raised when a chart fails validation","ref":"LiveCharts.ValidationError.html"},{"type":"extras","title":"LiveCharts","doc":"LiveCharts\n==========\n\n> LiveCharts allows you to render static and dynamic charts in Phoenix LiveView applications.\n\nLiveCharts currently comes with support for [ApexCharts][apexcharts] out of the box, but it\ncan work with any JS charting library that has a [`LiveCharts.Adapter`][docs-adapter] defined.\n\nTo see live demos, visit: [livecharts.stax3.com][demos].","ref":"readme.html"},{"type":"extras","title":"Installation - LiveCharts","doc":"Add `:live_charts` to your `mix.exs` dependencies:\n\n```elixir\ndefp deps do\n  [\n    {:live_charts, \"~> 0.3.0\"},\n  ]\nend\n```\n\nThen include the LiveCharts hooks in your `app.js`:\n\n```javascript\n// Import the JS file\nimport LiveCharts from \"live_charts\"\n\n// Include the hooks\nlet liveSocket = new LiveSocket(\"/live\", Socket, {\n  params: {_csrf_token: csrfToken},\n  hooks: {\n    // your other hooks...\n    // e.g. SomeCustomHook,\n\n    // Expand LiveCharts hooks at the end\n    ...LiveCharts.Hooks,\n  },\n});\n```","ref":"readme.html#installation"},{"type":"extras","title":"Configuration - LiveCharts","doc":"LiveCharts may optionally be configured to set the default adapter or JSON encoding library.\nIt currently defaults to the following:\n\n```elixir\n# config/config.exs\n\nconfig :live_charts,\n  adapter: LiveCharts.Adapter.ApexCharts,\n  json_library: Jason\n```","ref":"readme.html#configuration"},{"type":"extras","title":"Usage - LiveCharts","doc":"","ref":"readme.html#usage"},{"type":"extras","title":"Chart data - LiveCharts","doc":"LiveCharts tracks a chart's data and configuration in a [`%Chart{}`][docs-chart] struct.\nBefore it can be rendered, you need to build this struct.\n\n```elixir\nmy_chart =\n  LiveCharts.build(%{\n    # (Optional) a unique string id to differentiate the chart from other\n    # charts on the same page. If not set, a random id will be assigned\n    # to the chart.\n    id: \"my-custom-chart-id\",\n\n    # Set the chart type. Supports `:line`, `:bar`, `:pie`, `:donut`,\n    # `:area`, and many more. For a full list of supported types, see the\n    # adapter or JS library documentation.\n    type: :bar,\n\n    # A list of series data with all the datapoints to chart. Format of\n    # this data is determined by the adapter/JS library. This may also\n    # be empty, if you plan to push dynamic updates to the chart over\n    # the socket later.\n    series: [\n      %{name: \"Sales\", data: [10, 20, 30, 40, 50]},\n    ],\n\n    # (Optional) Other library and adapter-specific options.\n    options: %{\n      xaxis: %{\n        categories: [2021, 2022, 2023, 2024, 2025]\n      },\n    },\n\n    # (Optional) set the adapter to use for the chart. If not set, uses\n    # the global adapter configured in `config.exs` (defaults to\n    # `LiveCharts.Adapter.ApexCharts`).\n    adapter: LiveCharts.Adapter.ApexCharts,\n  })\n```\n\nFor a full list of options, see the official [ApexCharts docs][apexcharts-docs] and\nthe [`LiveCharts.Adapter.ApexCharts`][docs-apex] adapter information on HexDocs.\nYou can also [view live demos][demos] here.","ref":"readme.html#chart-data"},{"type":"extras","title":"Render Static Charts - LiveCharts","doc":"With a `LiveCharts.Chart` struct defined, you can now `assign` it in your liveview:\n\n```elixir\ndef mount(_params, _session, socket) do\n  socket =\n    socket\n    |> assign(:page_title, \"Page with charts!\")\n    |> assign(:my_chart, my_chart)\n\n  {:ok, socket}\nend\n```\n\nTo then render the chart in a heex template, use `LiveCharts.chart/1` component:\n\n```elixir\n \n```\n\nThis will re-render the chart on the page any time the `chart` assign is changed or updated.","ref":"readme.html#render-static-charts"},{"type":"extras","title":"Push Realtime/Dynamic updates to the Chart - LiveCharts","doc":"If the chart needs to be updated often, a better strategy is to only push the new data instead\nof rebuilding the entire chart and re-rendering it. You can do so by calling:\n\n```elixir\nLiveCharts.push_update(socket, chart.id, updated_series)\n```","ref":"readme.html#push-realtime-dynamic-updates-to-the-chart"},{"type":"extras","title":"Example - LiveCharts","doc":"Let's say we want to render a line chart that starts out empty, but as we get datapoints from\nan external source, we want to push them to the users' browsers.\n\nWe'll start by assigning a line chart to the LiveView:\n\n```elixir\n@impl true\ndef mount(_params, _session, socket) do\n  # Build an empty chart with custom settings\n  chart = LiveCharts.build(%{\n    type: :line,\n    series: [],\n    options: %{\n      xaxis: %{type: \"datetime\"},\n      yaxis: %{min: 0, max: 100},\n      chart: %{\n        animations: %{enabled: true, easing: \"linear\"},\n        zoom: %{enabled: false}\n      }\n    }\n  })\n\n  socket =\n    socket\n    |> assign(:chart, chart)\n    |> assign(:chart_data, [])\n\n  {:ok, socket}\nend\n```\n\nThen, render the empty chart in your heex template:\n\n```elixir\n \n```\n\nAssuming you already have a mechanism in place to receive new data points in the liveview, you\ncan then update the chart data and push it over the socket:\n\n```elixir\n@impl true\ndef handle_info({:chart_datapoint, {x, y}}, socket) do\n  %{chart: chart, chart_data: data} = socket.assigns\n\n  data = [%{x: x, y: y} | data]\n  series = [%{data: Enum.reverse(data)}]\n\n  socket =\n    socket\n    |> assign(:chart_data, data)\n    |> LiveCharts.push_update(chart, series)\n\n  {:noreply, socket}\nend\n```\n\nWe have used `handle_info/2` here, but chart updates could just as easily be pushed from other\nliveview callbacks. E.g. from `handle_event/3` when the user triggers an event or\n`handle_async/3` when an async task is completed.\n\nA live demo is also available on [livecharts.stax3.com][demos].","ref":"readme.html#example"},{"type":"extras","title":"Looking for help with your Elixir project? - LiveCharts","doc":"[Stax3][stax3] helps startups craft expressive and engaging solutions for their software needs.\nIf you're looking for expertise for your Elixir/Phoenix projects, we can help! Talk to us at\n[contact@stax3.com][email].","ref":"readme.html#looking-for-help-with-your-elixir-project"},{"type":"extras","title":"License - LiveCharts","doc":"LiveCharts is licensed under the [MIT License][license].\n\n\n\n\n[license]:          https://opensource.org/license/mit\n[hexpm]:            https://hex.pm/packages/live_charts\n[apexcharts]:       https://apexcharts.com\n[apexcharts-docs]:  https://apexcharts.com/docs/\n[demos]:            https://livecharts.stax3.com/\n[stax3]:            https://stax3.com\n[email]:            mailto:contact@stax3.com\n\n[docs]:             https://hexdocs.pm/live_charts\n[docs-chart]:       https://hexdocs.pm/live_charts/LiveCharts.Chart.html\n[docs-adapter]:     https://hexdocs.pm/live_charts/LiveCharts.Adapter.html\n[docs-apex]:        https://hexdocs.pm/live_charts/LiveCharts.Adapter.ApexCharts.html","ref":"readme.html#license"}],"proglang":"elixir","content_type":"text/markdown","producer":{"name":"ex_doc","version":"0.35.1"}}